searchNodes=[{"doc":"This module defines function for manipulating nested changesets. All functions take a path as the second argument. The path is a list of atoms (for field names) and integers (for indexes in lists).","ref":"EctoNestedChangeset.html","title":"EctoNestedChangeset","type":"module"},{"doc":"Appends a value to the field referenced by the path. The last path segment must be an atom referencing either a to-many relation field or an array field. Example iex&gt; % Owner { pets : [ % Pet { } , % Pet { toys : [ % Toy { name : &quot;stick&quot; } ] } ] } ...&gt; |&gt; Ecto.Changeset . change ( ) ...&gt; |&gt; append_at ( changeset , [ :pets , 1 , :toys ] , % Toy { name : &quot;ball&quot; } ) ...&gt; |&gt; Ecto.Changeset . apply_changes ( ) % Owner { pets : [ % Pet { } , % Pet { toys : [ % Toy { name : &quot;stick&quot; } , % Toy { name : &quot;ball&quot; } ] } ] }","ref":"EctoNestedChangeset.html#append_at/3","title":"EctoNestedChangeset.append_at/3","type":"function"},{"doc":"Deletes the item at the given path. The last path segment is expected to be an integer index. Items that are not persisted in the database yet will always be removed from the list. For structs that are already persisted in the database, there are three different modes. [mode: {:action, :replace}] (default) - The item will be wrapped in a changeset with the :replace action. This only works if an appropriate :on_replace option is set for the relation in the schema. [mode: {:action, :delete}] - The item will be wrapped in a changeset with the action set to :delete . [mode: {:flag, field}] - Puts true as a change for the given field. The flag option useful for explicitly marking items for deletion in form parameters. In this case, you would configure a virtual field on the schema and set the changeset action to :delete in the changeset function in case the value is set to true . schema &quot;pets&quot; do field :name , :string field :delete , :boolean , virtual : true , default : false end def changeset ( pet , attrs ) do pet |&gt; cast ( attrs , [ :name , :delete ] ) |&gt; validate_required ( [ :name ] ) |&gt; maybe_mark_for_deletion ( ) end def maybe_mark_for_deletion ( % Ecto.Changeset { } = changeset ) do if Ecto.Changeset . get_change ( changeset , :delete ) , do : Map . put ( changeset , :action , :delete ) , else : changeset end Examples iex&gt; changeset = Ecto.Changeset . change ( % Owner { pets : [ % Pet { name : &quot;George&quot; } , % Pet { name : &quot;Patty&quot; } ] } ...&gt; ) iex&gt; delete_at ( changeset , [ :pets , 1 ] ) % Ecto.Changeset { changes : [ % Changeset { action : :replace , data : % Post { name : &quot;Patty&quot; } } , % Changeset { action : :update , data : % Post { name : &quot;George&quot; } } , ] } iex&gt; delete_at ( changeset , [ :pets , 1 ] , mode : { :action , :delete } ) % Ecto.Changeset { changes : [ % Changeset { action : :update , data : % Post { name : &quot;George&quot; } } , % Changeset { action : :delete , data : % Post { name : &quot;Patty&quot; } } , ] } iex&gt; delete_at ( changeset , [ :pets , 1 ] , mode : { :field , :delete } ) % Ecto.Changeset { changes : [ % Changeset { action : :update , data : % Post { name : &quot;George&quot; } } , % Changeset { action : :update , changes : %{ delete : true } , data : % Post { name : &quot;Patty&quot; } } , ] }","ref":"EctoNestedChangeset.html#delete_at/3","title":"EctoNestedChangeset.delete_at/3","type":"function"},{"doc":"Returns a value from a changeset referenced by the path. Example iex&gt; % Owner { pets : [ % Pet { } , % Pet { toys : [ % Toy { name : &quot;stick&quot; } ] } ] } ...&gt; |&gt; Ecto.Changeset . change ( ) ...&gt; |&gt; get_at ( changeset , [ :pets , 1 , :toys ] ) [ % Toy { name : &quot;stick&quot; } , % Toy { name : &quot;ball&quot; } ]","ref":"EctoNestedChangeset.html#get_at/2","title":"EctoNestedChangeset.get_at/2","type":"function"},{"doc":"Inserts a value into a field at the given position. The last path segment must be an integer for the position. Example iex&gt; % Owner { ...&gt; pets : [ ...&gt; % Pet { } , ...&gt; % Pet { toys : [ % Toy { name : &quot;stick&quot; } , % Toy { name : &quot;ball&quot; } ] } ...&gt; ] ...&gt; } ...&gt; |&gt; Ecto.Changeset . change ( ) ...&gt; |&gt; insert_at ( changeset , [ :pets , 1 , :toys , 1 ] , % Toy { name : &quot;rope&quot; } ) ...&gt; |&gt; Ecto.Changeset . apply_changes ( ) % Owner { pets : [ % Pet { } , % Pet { toys : [ % Toy { name : &quot;ball&quot; } , % Toy { name : &quot;rope&quot; } , % Toy { name : &quot;stick&quot; } ] } ] }","ref":"EctoNestedChangeset.html#insert_at/3","title":"EctoNestedChangeset.insert_at/3","type":"function"},{"doc":"Prepends a value to the field referenced by the path. The last path segment must be an atom referencing either a to-many relation field or an array field. Example iex&gt; % Owner { pets : [ % Pet { } , % Pet { toys : [ % Toy { name : &quot;stick&quot; } ] } ] } ...&gt; |&gt; Ecto.Changeset . change ( ) ...&gt; |&gt; prepend_at ( changeset , [ :pets , 1 , :toys ] , % Toy { name : &quot;ball&quot; } ) ...&gt; |&gt; Ecto.Changeset . apply_changes ( ) % Owner { pets : [ % Pet { } , % Pet { toys : [ % Toy { name : &quot;ball&quot; } , % Toy { name : &quot;stick&quot; } ] } ] }","ref":"EctoNestedChangeset.html#prepend_at/3","title":"EctoNestedChangeset.prepend_at/3","type":"function"},{"doc":"Updates the value in the changeset at the given position with the given update function. The path may lead to any field, including arrays and relation fields. Unlike Ecto.Changeset.update_change/3 , the update function is always applied, either to the change or to existing value. If the path points to a field with a simple type, the update function will receive the raw value of the field. However, if the path points to the field of a *-to-many relation, the list values will not be unwrapped, which means that the update function has to handle a list of changesets. Examples iex&gt; % Owner { pets : [ % Pet { toys : [ % Toy { name : &quot;stick&quot; } , % Toy { name : &quot;ball&quot; } ] } ] } ...&gt; |&gt; Ecto.Changeset . change ( ) ...&gt; |&gt; update_at ( ...&gt; changeset , ...&gt; [ :pets , 1 , :toys , 1 , :name ] , ...&gt; &amp; String . upcase / 1 ...&gt; ) ...&gt; |&gt; Ecto.Changeset . apply_changes ( ) % Owner { pets : [ % Pet { } , % Pet { toys : [ % Toy { name : &quot;stick&quot; } , % Toy { name : &quot;BALL&quot; } ] } ] }","ref":"EctoNestedChangeset.html#update_at/3","title":"EctoNestedChangeset.update_at/3","type":"function"},{"doc":"Raised when a relation field that is updated is not preloaded.","ref":"EctoNestedChangeset.NotLoadedError.html","title":"EctoNestedChangeset.NotLoadedError","type":"exception"},{"doc":"EctoNestedChangeset This is a package for manipulating nested Ecto changesets.","ref":"readme.html","title":"README","type":"extras"},{"doc":"Add ecto_nested_changeset to your list of dependencies in mix.exs : def deps do [ { :ecto_nested_changeset , &quot;~&gt; 0.2.1&quot; } ] end","ref":"readme.html#installation","title":"README - Installation","type":"extras"},{"doc":"The primary use case of this library is the manipulation of Ecto changesets used as a source for dynamic, nested forms in Phoenix LiveView . category = % Category { posts : [ % Post { id : 1 , comments : [ % Comment { body : &quot;potato&quot; , id : 1 } , % Comment { body : &quot;you&quot; , id : 2 } ] , title : &quot;must&quot; } , % Post { comments : [ ] , id : 2 , title : &quot;young&quot; } ] } category |&gt; Ecto.Changeset . change ( ) |&gt; append_at ( :posts , % Post { title : &quot;Padawan&quot; , comments : [ ] } ) |&gt; prepend_at ( [ :posts , 0 , :comments ] , % Comment { body : &quot;ecneitaP&quot; } ) |&gt; delete_at ( [ :posts , 0 , :comments , 1 ] , mode : { :action , :delete } ) |&gt; insert_at ( [ :posts , 1 ] , % Post { title : &quot;have&quot; } ) |&gt; append_at ( [ :posts , 2 , :comments ] , % Comment { body : &quot;my&quot; } ) |&gt; update_at ( [ :posts , 0 , :comments , 0 , :body ] , &amp; String . reverse / 1 ) |&gt; Ecto.Changeset . apply_changes ( ) % Category { posts : [ % Post { comments : [ % Comment { body : &quot;Patience&quot; } , % Comment { body : &quot;you&quot; , id : 2 } ] , id : 1 , title : &quot;must&quot; } , % Post { title : &quot;have&quot; } , % Post { comments : [ % Comment { body : &quot;my&quot; } ] , id : 2 , title : &quot;young&quot; } , % Post { title : &quot;Padawan&quot; } ] }","ref":"readme.html#usage","title":"README - Usage","type":"extras"},{"doc":"There is an example Phoenix application with a dynamic nested LiveView form in the /example folder of the repository. git clone https://github.com/woylie/ecto_nested_changeset.git cd ecto_nested_changeset/example mix setup mix phx.server Note that Postgres needs to be running to use the application. You can access the application at http://localhost:4000 .","ref":"readme.html#example-application","title":"README - Example application","type":"extras"},{"doc":"This library has a very narrow purpose, which means that even though it is young, it is unlikely that new functionality is going to be added or that the API is going to change. Should you miss something, though, don't hesitate to open an issue. Any issues and problems that may arise will be dealt with swiftly.","ref":"readme.html#status","title":"README - Status","type":"extras"}]